# Project Documentation

## Installation Requirements

```bash
pip install numpy
pip install pandas
pip install matplotlib
pip install scipy
pip install scikit-learn
```

## Project Structure

```
project/
├── envs.py              # Environment implementations
├── experiments.py       # Experiment runner and configurations
├── policies.py          # Bandit algorithm implementations
├── plotting.py          # Visualization utilities
├── utils.py            # Helper functions and classes
├── run_experiments.ipynb    # Main experiment runner notebook
└── reproduce_experiments.ipynb  # Experiment reproduction notebook
```

## Key Components

### 1. Algorithms Implemented

- TS-MR: Thompson Sampling with Maximum Regret (Proxy)
- Greedy-MR: Greedy with Maximum Regret (Proxy)
- LinTS: Linear Thompson Sampling
- TS-Freq: Frequentist variant of LinTS
- OFUL: Optimism in the Face of Uncertainty Linear bandits
- Greedy: Greedy Algorithm

### 2. Environment Types

#### Synthetic environments
- Example 1, 2, and 3 in the paper

#### Real dataset environments
- [Cardiotocography](https://www.openml.org/d/1466)
- [JapaneseVowels](https://www.openml.org/d/375)
- [Segment](https://www.openml.org/d/36)

### 3. Main Functions

#### **Running Experiments**

```python
from experiments import run_simulation

# Example usage
params = {
    'n': 100,              # Number of runs
    'k': 10,               # Number of actions
    'd': 50,               # Dimension
    't': 2500,             # Time horizon
    's': 1,                # Random seed
    'prior_mu': 0.0,       # Prior mean
    'prior_sd': 10.0,      # Prior standard deviation
    'noise_sd': 1.0,       # Noise standard deviation
    'sim': 'geo_aware_ex2', # Simulation type
    'radius': 70.0,        # Radius parameter
    'mu_TS': 12.0,         # mu threshold for TS-MR
    'mu_Greedy': 12.0      # mu threshold for Greedy-MR
}
run_simulation(**params)
```

#### **Reproducing Results**

**The raw experimental data is already included in the repository, so you can directly generate plots using the following function. This will create visualizations for cumulative regret and OFUL action fraction.**

```python
from experiments import plot_saved_results

# Example usage
plot_saved_results("sim_geo_aware_ex2_n_100_k_10_t_2500_r_70.0_pm_0.0_ps_10.0_ns_1.0_mts_12.0_mg_12.0_ds_None")
```


## Output and Visualization

The project generates:
- CSV files with experimental results
- Visualization plots including:
  - Cumulative regret
  - OFUL action fraction


Results are saved in:
- `my_outputs/`: Raw experimental data (already included)
- `figures/`: Generated plots and visualizations

## Dataset Requirements

Real-world datasets should be placed in a `datasets/` directory in ARFF format:
- `cardiotocography.arff`
- `JapaneseVowels.arff`
- `segment.arff`
